@@ -172,7 +172,7 @@ KEYWORDS = {
     'FULL': tokens.Keyword,
     'FUNCTION': tokens.Keyword,
 
-    'G': tokens.Keyword,
+#    'G': tokens.Keyword,
     'GENERAL': tokens.Keyword,
     'GENERATED': tokens.Keyword,
     'GET': tokens.Keyword,
@@ -219,7 +219,7 @@ KEYWORDS = {
     'ISOLATION': tokens.Keyword,
     'ITERATE': tokens.Keyword,
 
-    'K': tokens.Keyword,
+#    'K': tokens.Keyword,
     'KEY': tokens.Keyword,
     'KEY_MEMBER': tokens.Keyword,
     'KEY_TYPE': tokens.Keyword,
@@ -244,7 +244,7 @@ KEYWORDS = {
     'LOCK': tokens.Keyword,
     'LOWER': tokens.Keyword,
 
-    'M': tokens.Keyword,
+#    'M': tokens.Keyword,
     'MAP': tokens.Keyword,
     'MATCH': tokens.Keyword,
     'MAXVALUE': tokens.Keyword,
@@ -343,7 +343,6 @@ KEYWORDS = {
     'RELATIVE': tokens.Keyword,
     'RENAME': tokens.Keyword,
     'REPEATABLE': tokens.Keyword,
-    'REPLACE': tokens.Keyword,
     'RESET': tokens.Keyword,
     'RESTART': tokens.Keyword,
     'RESTRICT': tokens.Keyword,
@@ -400,7 +399,7 @@ KEYWORDS = {
     'SQLERROR': tokens.Keyword,
     'SQLEXCEPTION': tokens.Keyword,
     'SQLSTATE': tokens.Keyword,
-    'SQLWARNINIG': tokens.Keyword,
+    'SQLWARNING': tokens.Keyword,
     'STABLE': tokens.Keyword,
     'START': tokens.Keyword,
     'STATE': tokens.Keyword,
@@ -528,6 +527,7 @@ KEYWORDS_COMMON = {
     'INSERT': tokens.Keyword.DML,
     'DELETE': tokens.Keyword.DML,
     'UPDATE': tokens.Keyword.DML,
+    'REPLACE': tokens.Keyword.DML,
     'DROP': tokens.Keyword.DDL,
     'CREATE': tokens.Keyword.DDL,
     'ALTER': tokens.Keyword.DDL,
