@@ -150,7 +150,7 @@ class LexerMeta(type):
         return type.__call__(cls, *args, **kwds)
 
 
-class Lexer:
+class Lexer(object):
 
     __metaclass__ = LexerMeta
 
@@ -172,22 +172,29 @@ class Lexer:
             (r':=', tokens.Assignment),
             (r'::', tokens.Punctuation),
             (r'[*]', tokens.Wildcard),
+            (r'CASE\b', tokens.Keyword),  # extended CASE(foo)
             (r"`(``|[^`])*`", tokens.Name),
             (r"´(´´|[^´])*´", tokens.Name),
+            (r'\$([a-zA-Z_][a-zA-Z0-9_]*)?\$', tokens.Name.Builtin),
+            (r'\?{1}', tokens.Name.Placeholder),
+            (r'[$:?%][a-zA-Z0-9_]+[^$:?%]?', tokens.Name.Placeholder),
             (r'@[a-zA-Z_][a-zA-Z0-9_]+', tokens.Name),
+            (r'[a-zA-Z_][a-zA-Z0-9_]*(?=[.(])', tokens.Name),  # see issue39
             (r'[<>=~!]+', tokens.Operator.Comparison),
             (r'[+/@#%^&|`?^-]+', tokens.Operator),
+            (r'0x[0-9a-fA-F]+', tokens.Number.Hexadecimal),
+            (r'[0-9]*\.[0-9]+', tokens.Number.Float),
             (r'[0-9]+', tokens.Number.Integer),
             # TODO: Backslash escapes?
             (r"(''|'.*?[^\\]')", tokens.String.Single),
             # not a real string literal in ANSI SQL:
             (r'(""|".*?[^\\]")', tokens.String.Symbol),
+            (r'(\[.*[^\]]\])', tokens.Name),
             (r'(LEFT |RIGHT )?(INNER |OUTER )?JOIN\b', tokens.Keyword),
             (r'END( IF| LOOP)?\b', tokens.Keyword),
             (r'NOT NULL\b', tokens.Keyword),
             (r'CREATE( OR REPLACE)?\b', tokens.Keyword.DDL),
             (r'[a-zA-Z_][a-zA-Z0-9_]*', is_keyword),
-            (r'\$([a-zA-Z_][a-zA-Z0-9_]*)?\$', tokens.Name.Builtin),
             (r'[;:()\[\],\.]', tokens.Punctuation),
         ],
         'multiline-comments': [
