@@ -103,3 +103,10 @@ class SQLSplitTest(TestCaseBase):
                'SELECT 2;')
         stmts = sqlparse.split(sql)
         self.assertEqual(len(stmts), 2)
+
+    def test_if_function(self):  # see issue 33
+        # don't let IF as a function confuse the splitter
+        sql = ('CREATE TEMPORARY TABLE tmp SELECT IF(a=1, a, b) AS o FROM one; '
+               'SELECT t FROM two')
+        stmts = sqlparse.split(sql)
+        self.assertEqual(len(stmts), 2)
